@@ -5,6 +5,7 @@ __all__ = (
     "c_malloc",
     "c_free",
     "c_realloc",
+    "c_calloc"
 )
 
 dll = ctypes.CDLL(
@@ -21,8 +22,11 @@ dll.free.restype = None
 # void* realloc(void* ptr, size_t size);
 dll.realloc.argtypes = (ctypes.c_void_p, ctypes.c_size_t)
 dll.realloc.restype = ctypes.c_void_p
-
+# void* calloc (size_t num, size_t size);
+dll.calloc.argtypes = (ctypes.c_size_t, ctypes.c_size_t)
+dll.calloc.restype = ctypes.c_void_p
 
 c_malloc = dll.malloc
 c_free = dll.free
 c_realloc = dll.realloc
+c_calloc = dll.calloc
